@@ -1,3 +1,57 @@
+"""
+JAFARI: :class:`Method`
+    0, Shia Ithna-Ashari, Leva Institute, Qum
+
+KARACHI: :class:`Method`
+    1, University of Islamic Sciences, Karachi
+
+ISNA: :class:`Method`
+    2, Islamic Society of North America (ISNA)
+
+MWL: :class:`Method`
+    3, Muslim World League
+
+MAKKAH: :class:`Method`
+    4, Umm Al-Qura University Makkah
+
+EGYPT: :class:`Method`
+    5, Egyptian General Authority of Survey
+
+.. note::
+    There is no 6 (method 6 is apparently same as 2).
+
+TEHRAN: :class:`Method`
+    7, Institute of Geophysics, University of Tehran
+
+GULF: :class:`Method`
+    8, Gulf Region
+
+KUWAIT: :class:`Method`
+    9, Kuwait
+
+QATAR: :class:`Method`
+    10, Qatar
+
+SINGAPORE: :class:`Method`
+    11, Majlis Ugama Islam Singapura, Singapore
+
+FRANCE: :class:`Method`
+    12, Union Organization Islamic de France
+
+TURKEY: :class:`Method`
+    13, Diyanet \u0130\u015fleri Ba\u015fkanl\u0131\u011f\u0131, Turkey
+
+RUSSIA: :class:`Method`
+    14, Spiritual Administration of Muslims of Russia
+
+MOONSIGHTING: :class:`Method`
+    15, Moonsighting Committee Worldwide (Moonsighting.com)
+
+all_methods: dict[:class:`int`, :class:`Method`]
+    A dict of each id and its method.
+"""
+
+
 class Method:
     """
     Represents a Method Calculation obj.
@@ -20,13 +74,10 @@ class Method:
         self.id = id
         self.params = params
 
-    def __str__(self):
-        return "<Method name={0.name!r}, id={0.id}, params={0.params}>".format(self)
+    def __repr__(self):  # pragma: no cover
+        return "<Method name={0.name!r}, id={0.id}>".format(self)
 
-    def __repr__(self):
-        return "<Method object>"
-
-    def __hash__(self):
+    def __hash__(self):  # pragma: no cover
         return hash((self.name, self.id))
 
 
@@ -47,7 +98,9 @@ ISNA = Method(
 )
 MWL = Method(name="Muslim World League", id=3, params={"Fajr": 18, "Isha": 17})
 MAKKAH = Method(
-    name="Umm Al-Qura University, Makkah", id=4, params={"Fajr": 18.5, "Isha": "90 min"}
+    name="Umm Al-Qura University, Makkah",
+    id=4,
+    params={"Fajr": 18.5, "Isha": "90 min"},
 )
 EGYPT = Method(
     name="Egyptian General Authority of Survey",
@@ -69,7 +122,9 @@ SINGAPORE = Method(
     params={"Fajr": 20, "Isha": 18},
 )
 FRANCE = Method(
-    name="Union Organization Islamic de France", id=12, params={"Fajr": 12, "Isha": 12}
+    name="Union Organization Islamic de France",
+    id=12,
+    params={"Fajr": 12, "Isha": 12},
 )
 TURKEY = Method(
     name="Diyanet \u0130\u015fleri Ba\u015fkanl\u0131\u011f\u0131, Turkey",
